@@ -128,6 +128,8 @@ struct subset_main_t : option_parser_t, face_options_t, output_options_t<false>
       write_file (output_file, result);
       hb_blob_destroy (result);
     }
+    else if (hb_face_get_glyph_count (orig_face) == 0)
+      fail (false, "Invalid font file.");
 
     hb_face_destroy (new_face);
     if (preprocess)
@@ -792,6 +794,7 @@ parse_file_for (const char *name,
       g_set_error (error, G_OPTION_ERROR, G_OPTION_ERROR_FAILED,
 		   "Failed reading file `%s': %s",
 		   arg, strerror (errno));
+      fclose (fp);
       return false;
     }
     g_string_append_c (gs, '\0');
@@ -812,6 +815,8 @@ parse_file_for (const char *name,
 
   g_string_free (gs, false);
 
+  fclose (fp);
+
   return true;
 }
 
@@ -853,7 +858,8 @@ subset_main_t::collect_rest (const char *name,
 void
 subset_main_t::add_options ()
 {
-  set_summary ("Subset fonts to specification.");
+  set_summary ("Subset font to specification.");
+  set_description ("Subsets font file to a specified set of glyphs, Unicode codepoints, or text, design-space limiting, and other reductions.");
 
   face_options_t::add_options (this);
 
@@ -926,9 +932,6 @@ subset_main_t::add_options ()
      "(Partially|Fully) Instantiate a variable font. A location consists of the tag "
      "of a variation axis, followed by '=', followed by a number or the literal "
      "string 'drop'. For example: --variations=\"wdth=100 wght=200\" or --variations=\"wdth=drop\""
-#ifndef HB_EXPERIMENTAL_API
-     "\n\nNote: currently only full instancing is supported unless this util has been compiled with experimental api enabled."
-#endif
      ,
      "list of comma separated axis-locations."
      },
@@ -963,8 +966,8 @@ subset_main_t::add_options ()
      "If set preprocesses the face with the add accelerator option before actually subsetting.", nullptr},
 #ifdef HB_EXPERIMENTAL_API
     {"iftb-requirements",	0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (gpointer) &set_flag<HB_SUBSET_FLAGS_IFTB_REQUIREMENTS>,	"Enforce requirements needed to use the subset with incremental font transfer IFTB patches.", nullptr},
-    {"optimize",		0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (gpointer) &set_flag<HB_SUBSET_FLAGS_OPTIMIZE_IUP_DELTAS>,		"Perform IUP delta optimization on the resulting gvar table's deltas", nullptr},
 #endif
+    {"optimize",		0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (gpointer) &set_flag<HB_SUBSET_FLAGS_OPTIMIZE_IUP_DELTAS>,	"Perform IUP delta optimization on the resulting gvar table's deltas", nullptr},
     {nullptr}
   };
   add_group (flag_entries,
